Examples - Trident Chemwidgets - Docs v0.1

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Toggle table of contents sidebar

# Examples

This section contains several examples generated from Jupyter notebooks. The widgets have been embedded into the page for demonstrative purposes.

- Using the Histogram widget
- Using the InteractiveMolecule widget
- Using the JSME widget
  - Using a base SMILES string for derivative molecules
- Using the Scatter widget